@@ -41,6 +41,8 @@ def _metadata_helper(source: FileTileSource, metadata: dict):
     if metadata['geospatial']:
         metadata['bounds'] = get_bounds(source)
         metadata['proj4'] = (source.getProj4String(),)
+    if 'frames' not in metadata:
+        metadata['frames'] = False
 
 
 def get_metadata(source: FileTileSource) -> dict:
